@@ -1,7 +1,7 @@
 # ABSTRACT: Dancer2's Domain Specific Language (DSL)
 
 package Dancer2::Core::DSL;
-$Dancer2::Core::DSL::VERSION = '0.140001';
+$Dancer2::Core::DSL::VERSION = '0.140900_01';
 use Moo;
 use Carp;
 use Class::Load 'load_class';
@@ -134,7 +134,7 @@ sub prefix {
       : $app->lexical_prefix(@_);
 }
 
-sub halt { shift->app->context->halt }
+sub halt { shift->context->halt }
 
 sub _route_parameters {
     my ( $regexp, $code, $options );
@@ -257,7 +257,7 @@ sub push_header  { shift->response->push_header(@_) }
 sub header       { shift->response->header(@_) }
 sub headers      { shift->response->header(@_) }
 sub content_type { shift->response->content_type(@_) }
-sub pass         { shift->response->pass }
+sub pass         { shift->context->pass }
 
 #
 # Route handler helpers
@@ -313,12 +313,16 @@ sub send_error {
     my $serializer = $self->app->engine('serializer');
     my $x = Dancer2::Core::Error->new(
         message => $message,
-        context => $self->app->context,
+        context => $self->context,
         ( status => $status ) x !!$status,
         ( serializer => $serializer ) x !!$serializer,
     )->throw;
 
-    $x;
+    # return if there is a with_return coderef
+    $self->context->with_return->($x)
+      if $self->context->has_with_return;
+
+    return $x;
 }
 
 #
@@ -326,37 +330,37 @@ sub send_error {
 #
 
 sub from_json {
-    my $app = shift->app;
+    shift; # remove first element
     require 'Dancer2/Serializer/JSON.pm';
     Dancer2::Serializer::JSON::from_json(@_);
 }
 
 sub to_json {
-    my $app = shift->app;
+    shift; # remove first element
     require 'Dancer2/Serializer/JSON.pm';
     Dancer2::Serializer::JSON::to_json(@_);
 }
 
 sub from_yaml {
-    my $app = shift->app;
+    shift; # remove first element
     require 'Dancer2/Serializer/YAML.pm';
     Dancer2::Serializer::YAML::from_yaml(@_);
 }
 
 sub to_yaml {
-    my $app = shift->app;
+    shift; # remove first element
     require 'Dancer2/Serializer/YAML.pm';
     Dancer2::Serializer::YAML::to_yaml(@_);
 }
 
 sub from_dumper {
-    my $app = shift->app;
+    shift; # remove first element
     require 'Dancer2/Serializer/Dumper.pm';
     Dancer2::Serializer::Dumper::from_dumper(@_);
 }
 
 sub to_dumper {
-    my $app = shift->app;
+    shift; # remove first element
     require 'Dancer2/Serializer/Dumper.pm';
     Dancer2::Serializer::Dumper::to_dumper(@_);
 }
@@ -376,7 +380,7 @@ Dancer2::Core::DSL - Dancer2's Domain Specific Language (DSL)
 
 =head1 VERSION
 
-version 0.140001
+version 0.140900_01
 
 =head1 FUNCTIONS
 
