@@ -1,6 +1,6 @@
 package Dancer2::Logger::File;
 # ABSTRACT: file-based logging engine for Dancer2
-$Dancer2::Logger::File::VERSION = '0.140001';
+$Dancer2::Logger::File::VERSION = '0.140900_01';
 use Carp 'carp';
 use Moo;
 use Dancer2::Core::Types;
@@ -12,6 +12,20 @@ use Fcntl qw(:flock SEEK_END);
 use Dancer2::FileUtils qw(open_file);
 use IO::File;
 
+# FIXME: this is not a good way to do this
+has environment => (
+    is      => 'ro',
+    lazy    => 1,
+    default => sub { $_[0]->context->app->environment },
+);
+
+# FIXME: this is not a good way to do this
+has location => (
+    is      => 'ro',
+    lazy    => 1,
+    default => sub { $_[0]->context->app->config_location },
+);
+
 has log_dir => (
     is      => 'rw',
     isa     => Str,
@@ -27,8 +41,6 @@ has log_dir => (
     },
 );
 
-sub _build_log_dir {File::Spec->catdir( $_[0]->location, 'logs' )}
-
 has file_name => (
     is      => 'ro',
     isa     => Str,
@@ -36,23 +48,41 @@ has file_name => (
     lazy    => 1
 );
 
+has log_file => (
+    is      => 'ro',
+    isa     => Str,
+    lazy    => 1,
+    builder => '_build_log_file',
+);
+
+has fh => (
+    is      => 'ro',
+    lazy    => 1,
+    builder => '_build_fh',
+);
+
+sub _build_log_dir {File::Spec->catdir( $_[0]->location, 'logs' )}
+
 sub _build_file_name {$_[0]->environment . ".log"}
 
-has log_file => ( is => 'rw', isa => Str );
-has fh       => ( is => 'rw' );
-
-sub BUILD {
+sub _build_log_file {
     my $self = shift;
-    my $logfile = File::Spec->catfile( $self->log_dir, $self->file_name );
+    return File::Spec->catfile( $self->log_dir, $self->file_name );
+}
+
+sub _build_fh {
+    my $self    = shift;
+    my $logfile = $self->log_file;
 
     my $fh;
     unless ( $fh = open_file( '>>', $logfile ) ) {
         carp "unable to create or append to $logfile";
         return;
     }
+
     $fh->autoflush;
-    $self->log_file($logfile);
-    $self->fh($fh);
+
+    return $fh;
 }
 
 sub log {
@@ -82,7 +112,7 @@ Dancer2::Logger::File - file-based logging engine for Dancer2
 
 =head1 VERSION
 
-version 0.140001
+version 0.140900_01
 
 =head1 DESCRIPTION
 
